/*
		     Clipboard IO and Clipboard Browser
 */

#ifndef CLIPBOARD_H
#define CLIPBOARD_H

#include <sys/types.h>
#include <gtk/gtk.h>

extern guint8 *ClipboardFetchBinary(gint *length);
extern gint ClipboardPutBinary(const guint8 *data, gint length);

extern gint ClipboardBrowserInit(void);
extern void ClipboardBrowserMap(void);
extern void ClipboardBrowserUnmap(void);
extern void ClipboardBrowserShutdown(void);

#endif	/* CLIPBOARD_H */
